/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.command.lib;

/**
 * This class is a wrapper for standard preprocessor.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class PreProcessor
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Preprocess a file. Causes the current thread to wait
     * until end of the process.
     *
     * @param inputfile - The file to preprocess.
     * @param args - Arguments for the preprocessor.
     *
     * @return The file preprocessed, else null.
     **/
    public static java.io.File
    process(String inputfile, String args)
    {
        java.io.File tmpFile = null;
        Process cpp = null;
        int status = 0;

        System.out.println("Preprocessing file " + inputfile + "...");
        try
        {
            tmpFile = java.io.File.createTempFile("OpenCCM_preprocessor",".tmp");
            String cmd = "cpp " + args + " -o " + tmpFile.toString() + " " + inputfile;
            // System.out.println("Command : "+ cmd);
            // System.out.println("Output file = "+ tmpFile.toString());
            cpp = Runtime.getRuntime().exec( cmd );
            status = cpp.waitFor();
        }
        catch (Exception e)
        {
            System.err.println(e.getMessage());
            return null;
        }

        if (status != 0)
        {
            System.err.println("Preprocessing failed");
            return null;
        }

        System.out.println("File " + inputfile + " preprocessed");
        return tmpFile;
    }

}
