/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): .

====================================================================*/

package org.objectweb.corba.generator.common;


/** To access all the AST Declaration. */
import org.objectweb.corba.ast.api.Declaration;


/**
 * This interface allows naviguation in the OpenCCM AST
 * and calls to map files.
 **/
public interface GeneratorBaseOperations
         extends org.objectweb.corba.generator.common.GeneratorOperations
{

    /**
     * Is the declaration a business (i.e. a non system) declaration ?
     *
     * @param decl - The declaration.
     *
     * @return True if the declaration is business declaration, false otherwise.
     **/
    public boolean
    isBusinessDeclaration(Declaration decl);

    /**
     * Visit a  declaration in the repository
     *
     * @param obj - The declaration to visit.
     **/
    public void
    visit(Declaration obj);

    /**
     * Visit declarations.
     *
     * @param vect - A vector containing Declarations to visit.
     **/
    public void
    visit(org.objectweb.ccm.util.Vector vect);

    /**
     * Visit a single contained declaration
     *
     * @param contained - The declaration to visit.
     * @param extension - used to map id
     **/
    public void
    visitContained(Declaration contained, String extension);

    /**
     * Get a declaration.
     * name must be a valid declaration name.
     *
     * @param name - The name of the declaration to get.
     **/
    public Declaration
    getDeclaration(String name)
    throws org.objectweb.corba.generator.common.GenerationException;

    /**
     * Get contents of the root scope matching limited_types.
     *
     * @param limited_types - A logical combination of DeclarationKind.
     **/
    public org.objectweb.ccm.util.Vector
    getDeclarations(long limited_types)
    throws org.objectweb.corba.generator.common.GenerationException;
}
